/*
 * Copyright (c) 2008, Matthias Brantner, John Snelson
 * Please see LICENSE.txt for more information.
 */

#include "xqc.h"

#include <stdlib.h>

/**
 * This example demonstrates how a user can 
 * prepare and execute a query given an XQC_Implementation object. 
 * The result is printed to standard out.
 * Note that no error checking is done in this example.
 */
int
example_1(XQC_Implementation impl)
{
  XQC_Expression*  expr;
  FILE*            out = stdout;

  // prepare a query
  impl->prepare(impl, "(1, 2, 3, 4)", NULL, &expr);

  // execute it and print the result on standard out
  expr->execute(expr, NULL, out);

  // free the query
  expr->free(expr);

  return 1;
}

/**
 * This example demonstrates how a user can 
 * prepare a query and iterate over the result sequence.
 * The string-value of each item in the sequence is printed to standard out.
 * Note that no error checking is done in this example.
 */
int                                                                                                     
example_2(XQC_Implementation impl)
{
  XQC_Expression* expr;
  XQC_Sequence*   result;
  const char*     string_value;

  impl->prepare(impl, "for $i in 1 to 10 return $i", NULL, &expr);

  expr->sequence(expr, NULL, &result);

  while ( result->next(result) != XQC_END_OF_SEQUENCE ) {
    result->string_value(result, &string_value);
    printf("%s ", string_value);
  }

  result->free(lResult);
  expr->free(lXQuery);

  return 1;
}

int
main(int argc, char **argv) 
{
  XQC_Implementation impl;

  // system defined way to get the implementation struct
  // for example, for zorba it works as follows
  // if ( zorba_implementation(&impl) != XQ_SUCCESS )
  //   return 1;

  printf("executing example 1\n");
  res = example_1(impl);
  if (res == 0) { impl->free(impl); return 1; };
  printf("\n");

  printf("executing example 2\n");
  res = example_2(impl);
  if (res == 0) { impl->free(impl); return 1; };
  printf("\n");

  // release the implementation object
  impl->free(impl);

  return 0;

}
